TableBuilder

Struct TableBuilder 

pub struct TableBuilder { /* private fields */ }
Builder for constructing tables with a fluent API.

Provides methods for configuring table appearance, columns, and behavior before building the final table.

Examples

use sublime_cli_tools::output::table::{TableBuilder, TableTheme, ColumnAlignment};

let mut table = TableBuilder::new()
    .theme(TableTheme::Default)
    .columns(&["Name", "Version", "Type"])
    .alignment(1, ColumnAlignment::Right)
    .max_width(100)
    .build();

table.add_row(&["package", "1.0.0", "major"]);

Implementations

Source

impl TableBuilder

pub fn new() -> Self

Creates a new table builder with default settings.

Examples
use sublime_cli_tools::output::table::TableBuilder;

let builder = TableBuilder::new();
pub fn theme(self, theme: TableTheme) -> Self

Sets the table theme.

Examples
use sublime_cli_tools::output::table::{TableBuilder, TableTheme};

let builder = TableBuilder::new().theme(TableTheme::Minimal);
pub fn columns(self, columns: &[&str]) -> Self

Sets the column headers.

Examples
use sublime_cli_tools::output::table::TableBuilder;

let builder = TableBuilder::new()
    .columns(&["Package", "Version", "Type"]);
pub fn alignment(self, column_index: usize, alignment: ColumnAlignment) -> Self

Sets the alignment for a specific column.

Arguments
  • column_index - Zero-based column index
  • alignment - The alignment to apply
Examples
use sublime_cli_tools::output::table::{TableBuilder, ColumnAlignment};

let builder = TableBuilder::new()
    .columns(&["Name", "Count"])
    .alignment(1, ColumnAlignment::Right);
pub fn max_width(self, width: usize) -> Self

Sets the maximum table width in characters.

If not set, the terminal width is used automatically.

Examples
use sublime_cli_tools::output::table::TableBuilder;

let builder = TableBuilder::new().max_width(100);
pub fn min_column_width(self, width: usize) -> Self

Sets the minimum column width in characters.

Columns will not be narrower than this width unless the terminal is too narrow. Default is 10.

Examples
use sublime_cli_tools::output::table::TableBuilder;

let builder = TableBuilder::new().min_column_width(15);
pub fn build(self) -> Table

Builds the table with the configured settings.

Examples
use sublime_cli_tools::output::table::TableBuilder;

let table = TableBuilder::new()
    .columns(&["Name", "Value"])
    .build();